!= Sample program for gtool_history/gtool5
!
! * 2006/10/25 Y.Morikawa
! * 2003/08/21 M.Odaka
! * 2001/02/27 S.Takehiro
!
! Solving diffusion equation
! \[
!     du/dt = \kappa d^2 u/dx^2
! \]
! for giving values of $u$ at $x=[0,1]$.
!
program diffusion

  use gtool_history                                   ! ⥸塼

  integer, parameter     :: nx=30                   ! åɿ
  integer, parameter     :: nt=200                  ! ֥ƥå׿
  integer, parameter     :: ndisp=10                ! ϴֳ
  real(8), parameter     :: dx=1.0/(nx-1)           ! åɴֳ
  real(8), parameter     :: dt=0.0005               ! ֳִ
  real(8), dimension(nx) :: x=(/(dx*(i-1),i=1,nx)/) ! ɸѿ
  real(8), dimension(nx) :: temp                    ! 
  real(8), parameter     :: kappa=1.0               ! ǮȻ

  tinit = 0.0                                       ! 

  temp = exp(-((x-0.5)/0.1)**2)                     ! 

  call HistoryCreate( &                             ! ҥȥ꡼
    & file='diffusion_attr.nc', title='Diffusion equation', &
    & source='Sample program of gtool_history/gtool5',   &
    & institution='GFD_Dennou Club davis project',       &
    & dims=(/'x','t'/), dimsizes=(/nx,0/),               &
    & longnames=(/'X-coordinate','time        '/),       &
    & units=(/'m','s'/),                                 &
    & origin=real(tinit), interval=real(ndisp*dt) )

  call HistoryPut('x',x)                            ! ѿ

  call HistoryAddVariable( &                        ! ѿ
    & varname='temp', dims=(/'x','t'/), &
    & longname='temperature', units='K', xtype='double')

  call HistoryAddAttr('temp','gt_graph_tick_all',1)
  call HistoryAddAttr('temp','gt_graph_contour_spacing',(/0.0,1.0,0.01/))
  call HistoryAddAttr('temp','+gt_user_davis_kappa',kappa)

  call HistoryPut('temp',temp)                      ! ѿ

  do it=1,nt
    temp(2:nx-1) = temp(2:nx-1) &                   ! ʬ
      & + kappa*(temp(3:nx)-2*temp(2:nx-1)+temp(1:nx-2))/dx**2*dt

    if ( mod(it,ndisp) == 0 ) then
      call HistoryPut('temp',temp)                  ! ѿ
    endif
  enddo

  call HistoryClose
  stop
end program diffusion
